@@ -499,6 +499,7 @@ int32_t lk_karmaLan_read_file_chunk(int rio, uint64_t offset, uint64_t size,
 
 int32_t lk_karmaLan_delete_file(int rio, uint32_t file_id)
 {
+    int ret = 0;
     char id[4];
     
     file_id=lk_htorl(file_id);
@@ -508,10 +509,13 @@ int32_t lk_karmaLan_delete_file(int rio, uint32_t file_id)
         lk_properties_inc_devgeneration();
         if(recv_status(rio) != 0){
             lk_errors_set(E_FAILEDREQ);
-            return -1; /* err: failed request */
-        }else return 0;
+            ret = -1; /* err: failed request */
+        } /* else ret = 0; */
     }
-    else return -1; /* already set by busy_handler */
+    else ret = -1; /* already set by busy_handler */
+
+    if(!ret) lk_properties_del_property(file_id);
+    return ret;
 }
 
 /* Now, that command would be scary ;)
