@@ -937,6 +937,8 @@ int32_t lk_karmaUsb_delete_file(int rio, uint32_t file_id)
 
     if(ret == -1)
         lk_errors_set(E_DELETE);
+
+    if (!ret) lk_properties_del_property(file_id);
     free(path);
     return ret;
 }
@@ -978,6 +980,8 @@ void lk_karmaUsb_load_database_smalldb(int rio)
     if(properties)
         count = lk_properties_import(properties);
     /* else just assume a new blank DB */
+    else
+        lk_properties_init();
     
     lk_fdb_load(1);
 /*  fprintf(stderr, "smalldb: %d Files\n", count); */
